@@ -3,7 +3,7 @@
 
     AUTHORS:
 
-        mario.kleiner@tuebingen.mpg.de  mk
+        mario.kleiner.de@gmail.com  mk
 
     PLATFORMS:
 
@@ -291,10 +291,10 @@ unsigned int PsychSetGPUIdentityPassthrough(PsychWindowRecordType* windowRecord,
 #endif
 }
 
-/* PsychEnableNative10BitFramebuffer()  - Enable/Disable native 10 bpc RGB framebuffer modes.
+/* PsychEnableNative10BitFramebuffer()  - Enable/Disable native >= 10 bpc RGB framebuffer modes.
  *
- * This function enables or disables the native ARGB2101010 framebuffer readout mode of supported
- * graphics hardware. Currently the ATI Radeon X1000/HD2000/HD3000 and later cards should allow this.
+ * This function enables or disables the native high bit depth framebuffer readout modes of supported
+ * graphics hardware. Currently the ATI Radeon X1000, HD2000 and later cards do allow this.
  *
  * This needs support from the Psychtoolbox kernel level support driver for low-level register reads
  * and writes to the GPU registers.
@@ -304,7 +304,7 @@ unsigned int PsychSetGPUIdentityPassthrough(PsychWindowRecordType* windowRecord,
  *                  fixups. A value of NULL will try to apply the operation to all heads, but may only work
  *                  for *disabling* 10 bpc mode, not for enabling it -- Mostly useful for a master reset to
  *                  system default, e.g., as part of error handling or Screen shutdown handling.
- * 'enable'   True = Enable ABGR2101010 support, False = Disable ARGB2101010 support, reenable ARGB8888 support.
+ * 'enable'   True = Enable high bit depth support, False = Disable high bit depth support, reenable ARGB8888 support.
  *
  */
 psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord, psych_bool enable)
@@ -362,10 +362,10 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
                 // Enable:
 
                 // Switch hardware LUT's to bypass mode:
-                // We set bit 8 to enable "bypass LUT in 2101010 mode":
+                // We set bit 8 to enable "bypass LUT in 2101010 mode", aka bypass in all high bit depth modes:
                 value = PsychOSKDReadRegister(screenId, lutreg, &status);
                 if (status) {
-                    printf("PTB-ERROR: Failed to set 10 bit framebuffer mode (LUTReg read failed).\n");
+                    printf("PTB-ERROR: Failed to enable lut bypass framebuffer mode (LUTReg read failed).\n");
                     return(false);
                 }
 
@@ -374,33 +374,40 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
 
                 PsychOSKDWriteRegister(screenId, lutreg, value, &status);
                 if (status) {
-                    printf("PTB-ERROR: Failed to set 10 bit framebuffer mode (LUTReg write failed).\n");
+                    printf("PTB-ERROR: Failed to enable lut bypass framebuffer mode (LUTReg write failed).\n");
                     return(false);
                 }
 
                 // Only reconfigure framebuffer scanout if this is really our true Native10bpc hack:
                 // This is usually skipped on FireGL/FirePro GPU's as their drivers do it already...
                 if (windowRecord->specialflags & kPsychNative10bpcFBActive) {
-                    // Switch CRTC to ABGR2101010 readout mode:
-                    // We set bit 8 to enable that mode:
+                    // Switch CRTC to ABGR2101010 or BGR101111 or RGBA16161616 mode:
                     value = PsychOSKDReadRegister(screenId, ctlreg, &status);
                     if (status) {
-                        printf("PTB-ERROR: Failed to set 10 bit framebuffer mode (CTLReg read failed).\n");
+                        printf("PTB-ERROR: Failed to set high bit depth framebuffer mode (CTLReg read failed).\n");
                         return(false);
                     }
 
-                    // Set 2101010 mode bit:
-                    value = value | 0x1 << 8;
+                    if (windowRecord->depth == 48) {
+                        // Set bit 0 to switch from 32 bpp to 64 bpp framebuffer:
+                        value = value | (1 << 0);
+                    }
+                    else {
+                        // Set 2101010 or 101111 mode bits:
+                        value = value | (((windowRecord->depth == 33) ? 7 : 1) << 8);
+                    }
 
                     PsychOSKDWriteRegister(screenId, ctlreg, value, &status);
                     if (status) {
-                        printf("PTB-ERROR: Failed to set 10 bit framebuffer mode (CTLReg write failed).\n");
+                        printf("PTB-ERROR: Failed to set high bit depth framebuffer mode (CTLReg write failed).\n");
                         return(false);
                     }
-                }
 
-                // Pipe should be in 10 bpc mode now...
-                if (PsychPrefStateGet_Verbosity() > 2) printf("PTB-INFO: System framebuffer switched to ARGB2101010 mode for screen %i [head %i].\n", i, headid);
+                    // Pipe should be in 10 bpc mode now...
+                    if (PsychPrefStateGet_Verbosity() > 2) {
+                        printf("PTB-INFO: System framebuffer switched to %s mode for screen %i [head %i].\n", (windowRecord->depth == 48) ? "RGBA16161616" : (windowRecord->depth == 33) ? "BGR101111" : "ARGB2101010", i, headid);
+                    }
+                }
             } else {
                 // Disable:
 
@@ -408,7 +415,7 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
                 // This is usually skipped on FireGL/FirePro GPU's as their drivers do it already...
                 if (windowRecord->specialflags & kPsychNative10bpcFBActive) {
                     // Switch CRTC to ABGR8888 readout mode:
-                    // We clear bit 8 to enable that mode:
+                    // We clear bits 0 and 8:10 to enable that mode:
                     value = PsychOSKDReadRegister(screenId, ctlreg, &status);
                     if (status) {
                         // This codepath gets always called in PsychCloseWindow(), so we should skip it
@@ -417,43 +424,43 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
                         if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-ERROR: Failed to set 8 bit framebuffer mode (CTLReg read failed).\n");
                         return(false);
                     }
-                    else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable 10bpc: Readreg. ctlreg yields %lx\n", value);
+                    else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable high bit depth: Readreg. ctlreg yields %lx\n", value);
 
-                    // Clear 2101010 mode bit:
-                    value = value & ~(0x1 << 8);
+                    // Clear bits 0, 8:10 :
+                    value = value & ~((0x7 << 8) | 0x1);
 
                     PsychOSKDWriteRegister(screenId, ctlreg, value, &status);
                     if (status) {
                         printf("PTB-ERROR: Failed to set 8 bit framebuffer mode (CTLReg write failed).\n");
                         return(false);
                     }
-                    else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable 10bpc: ctlreg reset\n");
+                    else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable high bit depth: ctlreg reset\n");
 
                     // Wait 500 msecs for GPU to settle:
                     PsychWaitIntervalSeconds(0.5);
+
+                    // Pipe should be in 8 bpc mode now...
+                    if (PsychPrefStateGet_Verbosity() > 2) printf("PTB-INFO: System framebuffer switched to standard ARGB8888 mode for screen %i [head %i].\n", i, headid);
                 }
 
                 // Switch hardware LUT's to standard mapping mode:
                 // We clear bit 8 to disable "bypass LUT in 2101010 mode":
                 value = PsychOSKDReadRegister(screenId, lutreg, &status);
                 if (status) {
-                    printf("PTB-ERROR: Failed to set 8 bit framebuffer mode (LUTReg read failed).\n");
+                    printf("PTB-ERROR: Failed to disable lut bypass framebuffer mode (LUTReg read failed).\n");
                     return(false);
                 }
-                else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable 10bpc: Readreg. lutreg yields %lx\n", value);
+                else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable lut bypass: Readreg. lutreg yields %lx\n", value);
 
                 // Clear LUT bypass bit:
                 value = value & ~(0x1 << 8);
 
                 PsychOSKDWriteRegister(screenId, lutreg, value, &status);
                 if (status) {
-                    printf("PTB-ERROR: Failed to set 8 bit framebuffer mode (LUTReg write failed).\n");
+                    printf("PTB-ERROR: Failed to disable lut bypass framebuffer mode (LUTReg write failed).\n");
                     return(false);
                 }
-                else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable 10bpc: lutreg reset\n");
-
-                // Pipe should be in 8 bpc mode now...
-                if (PsychPrefStateGet_Verbosity() > 2) printf("PTB-INFO: System framebuffer switched to standard ARGB8888 mode for screen %i [head %i].\n", i, headid);
+                else if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: In disable lut bypass: lutreg reset\n");
             }
         } // Next display head...
     } // Next screenId.
@@ -471,13 +478,13 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
  *
  * Undo changes made by the graphics driver to the framebuffer pixel format control register
  * as part of an OpenGL/Graphics op that marks "End of Scene", e.g., a glClear() command, that
- * would revert the framebuffers opmode to standard 8bpc mode and thereby kill our 10 bpc mode
+ * would revert the framebuffers opmode to standard 8bpc mode and thereby kill our >= 10 bpc mode
  * setting.
  *
  * This routine *must* be called after each such problematic "End of scene" marker command like
  * glClear(). The routine does nothing if 10bpc mode is not enabled/requested for the corresponding
  * display head associated with the given onscreen window. It rewrites the control register on
- * 10 bpc configured windows to basically undo the unwanted change of the gfx-driver *before*
+ * >= 10 bpc configured windows to basically undo the unwanted change of the gfx-driver *before*
  * a vertical retrace cycle starts, ie., before that changes take effect (The register is double-
  * buffered and latched to update only at VSYNC time, so we just have to be quick enough).
  *
@@ -489,7 +496,7 @@ psych_bool	PsychEnableNative10BitFramebuffer(PsychWindowRecordType* windowRecord
  * 4. This routine undos the "bad" value change request by overwriting the latch with our
  *    "good" value --> Scheduled for next VSYNC. Then it returns...
  * 5. At next VSYNC or old "good" value is overwritten/latched with our new old "good" value,
- *    --> "good value" persists, framebuffer stays in 2101010 configuration --> All good.
+ *    --> "good value" persists, framebuffer stays in high bpc configuration --> All good.
  *
  * So far the theory, let's see if this really works in real world...
  *
@@ -556,17 +563,23 @@ void PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(PsychWindowReco
         if (PsychPrefStateGet_Verbosity() > 9) {
             val1 = PsychOSKDReadRegister(screenId, lutreg, NULL);
             val2 = PsychOSKDReadRegister(screenId, ctlreg, NULL);
-            printf("PTB-DEBUG: PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(): Screen %i, head %i: LUT = %i [%i], GRPHCONT = %i [%i]\n", screenId, headid, val1 & (0x1 << 8), val1, val2 & (0x1 << 8), val2);
+            printf("PTB-DEBUG: PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(): Screen %i, head %i: LUT = %i [%i], GRPHCONT = %i [%i]\n", screenId, headid, val1 & (0x1 << 8), val1, (val2 & (0x7 << 8)) >> 8, val2);
         }
 
         // One-liner read-modify-write op, which simply sets bit 8 of the register - the "10 bit LUT bypass" bit:
         PsychOSKDWriteRegister(screenId, lutreg, (0x1 << 8) | PsychOSKDReadRegister(screenId, lutreg, NULL), NULL);
 
-        // One-liner read-modify-write op, which simply sets bit 8 of the register - the "Enable 2101010 mode" bit:
-        PsychOSKDWriteRegister(screenId, ctlreg, (0x1 << 8) | PsychOSKDReadRegister(screenId, ctlreg, NULL), NULL);
+        if (windowRecord->depth == 48) {
+            // One-liner read-modify-write op, which simply sets bit 0 of the register - the "Enable 64 bpp mode" bit:
+            PsychOSKDWriteRegister(screenId, ctlreg, (0x1) | PsychOSKDReadRegister(screenId, ctlreg, NULL), NULL);
+        }
+        else {
+            // One-liner read-modify-write op, which simply sets bit 8 or bit 8:10 of the register - the "Enable 2101010 mode or Enable 101111 mode " bit:
+            PsychOSKDWriteRegister(screenId, ctlreg, (((windowRecord->depth == 33) ? 7 : 1) << 8) | PsychOSKDReadRegister(screenId, ctlreg, NULL), NULL);
+        }
 
         // Debug output, if wanted:
-        if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(): ARGB2101010 bit set on screen %i, head %i.\n", screenId, headid);
+        if (PsychPrefStateGet_Verbosity() > 5) printf("PTB-DEBUG: PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(): Control bits set on screen %i, head %i.\n", screenId, headid);
     }
 #endif
 
@@ -574,38 +587,147 @@ void PsychFixupNative10BitFramebufferEnableAfterEndOfSceneMarker(PsychWindowReco
     return;
 }
 
+/* PsychGetCurrentGPUSurfaceAddresses() - Get current scanout surface addresses
+ *
+ * Tries to get current addresses of primary and secondary scanout buffers and
+ * the pending status of pending pageflips if any.
+ *
+ * primarySurface - Pointer to 64-Bit target for frontBuffers address.
+ * secondarySurface - Pointer to a potential secondary buffer, e.g., for frame-sequential stereo.
+ * updatePending - TRUE if a flip has been queued and is still pending. FALSE otherwise or "don't know"
+ *
+ * Returns TRUE on success, FALSE if given GPU isn't supported for such queries.
+ *
+ */
+psych_bool PsychGetCurrentGPUSurfaceAddresses(PsychWindowRecordType* windowRecord, psych_uint64* primarySurface, psych_uint64* secondarySurface, psych_bool* updatePending)
+{
+    #if PSYCH_SYSTEM == PSYCH_OSX || PSYCH_SYSTEM == PSYCH_LINUX
+        int gpuMaintype, gpuMinortype;
+        unsigned int updateStatus;
+
+        // If we are called, we know that 'windowRecord' is an onscreen window.
+        int screenId = windowRecord->screenNumber;
+        int headid = PsychScreenToCrtcId(screenId, 0);
+
+        // Just need to check if GPU low-level access is supported:
+        if (!PsychOSIsKernelDriverAvailable(screenId)) return(FALSE);
+
+        // We only support AMD Radeon/Fire GPU's, nothing else:
+        if (!PsychGetGPUSpecs(screenId, &gpuMaintype, &gpuMinortype, NULL, NULL) || (gpuMaintype != kPsychRadeon)) {
+            return(FALSE);
+        }
+
+        // Driver is online: Read the registers, but only for primary crtc in a multi-crtc config:
+        if  (gpuMinortype < 40) {
+            // Pre DCE-4: AVIVO class display hardware:
+            *primarySurface = (psych_uint64) PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_PRIMARY_SURFACE_ADDRESS : RADEON_D2GRPH_PRIMARY_SURFACE_ADDRESS, NULL);
+            *secondarySurface = (psych_uint64) PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_SECONDARY_SURFACE_ADDRESS : RADEON_D2GRPH_SECONDARY_SURFACE_ADDRESS, NULL);
+            updateStatus = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_UPDATE : RADEON_D2GRPH_UPDATE, NULL);
+
+            *updatePending = (updateStatus & RADEON_SURFACE_UPDATE_PENDING) ? TRUE : FALSE;
+        }
+
+        if  (gpuMinortype >= 40) {
+            // DCE-4 or later display hardware:
+            if (headid < 0 || headid > DCE4_MAXHEADID) {
+                if (PsychPrefStateGet_Verbosity() > 1) printf("PTB-WARNING: PsychGetCurrentGPUSurfaceAddresses(): Invalid headId %i (greater than max %i) provided for DCE-4+ display engine!\n", headid, DCE4_MAXHEADID);
+                return(FALSE);
+            }
+
+            // DCE 4 and later has 64-Bit addresses split in high/low 32-bit regs:
+            *primarySurface =   ((psych_uint64) PsychOSKDReadRegister(screenId, EVERGREEN_GRPH_PRIMARY_SURFACE_ADDRESS_HIGH + crtcoff[headid], NULL) << 32) +
+                                ((psych_uint64) PsychOSKDReadRegister(screenId, EVERGREEN_GRPH_PRIMARY_SURFACE_ADDRESS + crtcoff[headid], NULL));
+            *secondarySurface = ((psych_uint64) PsychOSKDReadRegister(screenId, EVERGREEN_GRPH_SECONDARY_SURFACE_ADDRESS_HIGH + crtcoff[headid], NULL) << 32) +
+                                ((psych_uint64) PsychOSKDReadRegister(screenId, EVERGREEN_GRPH_SECONDARY_SURFACE_ADDRESS + crtcoff[headid], NULL));
+            updateStatus =      PsychOSKDReadRegister(screenId, EVERGREEN_GRPH_UPDATE + crtcoff[headid], NULL);
+
+            *updatePending = (updateStatus & EVERGREEN_GRPH_SURFACE_UPDATE_PENDING) ? TRUE : FALSE;
+        }
+
+        if (PsychPrefStateGet_Verbosity() > 14) {
+            printf("PTB-DEBUG: Screen %i: Head %i: primarySurface=%p : secondarySurface=%p : updateStatus=%i\n", screenId, PsychScreenToCrtcId(screenId, 0), *primarySurface, *secondarySurface, updateStatus);
+        }
+
+        // Success:
+        return(TRUE);
+    #else
+        // Not supported:
+        return(FALSE);
+    #endif
+}
+
 /* Stores content of GPU's surface address registers of the surfaces that
  * correspond to the windowRecords frontBuffers. Only called inside
- * PsychFlipWindowBuffers() immediately before triggering a double-buffer
+ * PsychExecuteBufferSwapPrefix() immediately before triggering a double-buffer
  * swap. The values are used as reference values: If another readout of
  * these registers shows values different from the ones stored preflip,
- * then that is a certain indicator that bufferswap has happened.
+ * then that is a certain indicator that bufferswap via pageflip has happened
+ * or will happen.
  */
 void PsychStoreGPUSurfaceAddresses(PsychWindowRecordType* windowRecord)
 {
+    psych_bool updatePending;
+    PsychGetCurrentGPUSurfaceAddresses(windowRecord, &(windowRecord->gpu_preflip_Surfaces[0]), &(windowRecord->gpu_preflip_Surfaces[1]), &updatePending);
+    return;
+}
 
-#if PSYCH_SYSTEM == PSYCH_OSX || PSYCH_SYSTEM == PSYCH_LINUX
-    int gpuMaintype, gpuMinortype;
+/* PsychIsGPUPageflipUsed() - Is a pageflip used on the GPU for buffer swaps at this moment?
+ *
+ * This routine compares preflip scanout addresses, as gathered via a previous PsychStoreGPUSurfaceAddresses()
+ * call prior to scheduling a swap, with the current addresses and update status. It should only be called
+ * after we detected bufferswap completion to check if the swap happened via pageflip and therefore our
+ * completion detection and timestamping is trustworthy, or if the swap happened by some other means like
+ * compositor or copyswap and therefore our results wrt. completion or timestamping are not trustworthy -
+ * at least not for conventional timestamping as used on OSX, or Linux without special OS support.
+ *
+ * The interesting scenario is if - after detection of swap completion by our conventional standard method
+ * for use with proprietary graphics drivers - the surface scanout addresses have changed and the flip is
+ * confirmed finished. In this case we can be somewhat certain that we triggered the pageflip and it completed,
+ * ie. the results for timestamping are trustworthy. This is indicated by return value 2. If a flip is used
+ * but still pending (value 1) although our code assumes swap has completed then a pageflip was likely queued
+ * by the desktop compositor and is still pending -> Timestamping not trustworthy. A value of 0 could indicate
+ * copyswap or a compositor to which we sent our updated composition source surface and posted damage, but which
+ * hasn't yet picked up on it or at least hasn't performed the full composition pass + queueing a pageflip.
+ *
+ * Ergo: For checking the trustworthiness of swap completion timestamping, the only "good" result is a
+ * return value of 2, a value of 0 or 1 is considered bad for timing, a value of -1 is non-diagnostic.
+ *
+ * As of beginning of March 2015, this routine can only be used with some confidence on Linux for conventional
+ * timestamping with the proprietary drivers and X11, as we know how X11 compositors work on Linux and what
+ * to expect. Use with FOSS graphics stack or on Wayland is not needed as we have much better facilities there.
+ * Additionally the PsychGetCurrentGPUSurfaceAddresses() support code is limited to AMD gpu's, so the only
+ * interesting/valid use cases are Linux/X11 + proprietary AMD Catalyst driver for some clever handling, and
+ * OSX + PsychtoolboxKernelDriver + AMD gpu for purely diagnostic use for manual diagnostic, not automatic
+ * problem solving!
+ *
+ * Return values:
+ * -1  == Unknown / Query unsupported.
+ *  0  == No.
+ *  1  == Yes, and the flip has been queued but is still pending, not finished.
+ *  2  == Yes, and the flip is finished.
+ *
+ */
+int PsychIsGPUPageflipUsed(PsychWindowRecordType* windowRecord)
+{
+    psych_uint64 primarySurface, secondarySurface;
+    psych_bool updatePending;
 
-    // If we are called, we know that 'windowRecord' is an onscreen window.
-    int screenId = windowRecord->screenNumber;
-
-    // Just need to check if GPU low-level access is supported:
-    if (!PsychOSIsKernelDriverAvailable(screenId)) return;
-
-    // We only support Radeon GPU's with pre DCE-4 display engine, nothing more recent:
-    if (!PsychGetGPUSpecs(screenId, &gpuMaintype, &gpuMinortype, NULL, NULL) ||
-        (gpuMaintype != kPsychRadeon) || (gpuMinortype >= 40)) {
-        return;
+    if (!PsychGetCurrentGPUSurfaceAddresses(windowRecord, &primarySurface, &secondarySurface, &updatePending)) {
+        // Query not possible/supported: Return "I don't know" value -1:
+        return(-1);
     }
 
-    // Driver is online: Read the registers, but only for primary crtc in a multi-crtc config:
-    windowRecord->gpu_preflip_Surfaces[0] = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_PRIMARY_SURFACE_ADDRESS : RADEON_D2GRPH_PRIMARY_SURFACE_ADDRESS, NULL);
-    windowRecord->gpu_preflip_Surfaces[1] = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_SECONDARY_SURFACE_ADDRESS : RADEON_D2GRPH_SECONDARY_SURFACE_ADDRESS, NULL);
+    // Scanout addresses changed since last PsychStoreGPUSurfaceAddresses() call?
+    // That would mean a pageflip was either queued or already executed, in any
+    // case, pageflip is used for bufferswap:
+    if (primarySurface != windowRecord->gpu_preflip_Surfaces[0] || secondarySurface != windowRecord->gpu_preflip_Surfaces[1]) {
+        // Pageflip in use. Still pending (queued but not completed) or already completed?
+        if (updatePending) return(1);
+        return(2);
+    }
 
-#endif
-
-    return;
+    // Nope, scanout hasn't changed: Assume copyswap/blit etc.
+    return(0);
 }
 
 /*  PsychWaitForBufferswapPendingOrFinished()
@@ -625,52 +747,34 @@ psych_bool PsychWaitForBufferswapPendingOrFinished(PsychWindowRecordType* window
 {
 #if PSYCH_SYSTEM == PSYCH_OSX || PSYCH_SYSTEM == PSYCH_LINUX
     int gpuMaintype, gpuMinortype;
-
     CGDirectDisplayID displayID;
-    unsigned int primarySurface, secondarySurface;
-    unsigned int updateStatus;
     double deadline = *timestamp;
 
     // If we are called, we know that 'windowRecord' is an onscreen window.
     int screenId = windowRecord->screenNumber;
+    int headid = PsychScreenToCrtcId(screenId, 0);
 
     // Retrieve display id and screen size spec that is needed later...
     PsychGetCGDisplayIDFromScreenNumber(&displayID, screenId);
 
-#define RADEON_D1GRPH_UPDATE	0x6144
-#define RADEON_D2GRPH_UPDATE	0x6944
-#define RADEON_SURFACE_UPDATE_PENDING 4
-#define RADEON_SURFACE_UPDATE_TAKEN   8
-
     // Just need to check if GPU low-level access is supported:
     if (!PsychOSIsKernelDriverAvailable(screenId)) return(FALSE);
 
-    // We only support Radeon GPU's with pre DCE-4 display engine, nothing more recent:
-    if (!PsychGetGPUSpecs(screenId, &gpuMaintype, &gpuMinortype, NULL, NULL) ||
-        (gpuMaintype != kPsychRadeon) || (gpuMinortype >= 40)) {
+    // We only support AMD GPU's:
+    if (!PsychGetGPUSpecs(screenId, &gpuMaintype, &gpuMinortype, NULL, NULL) || (gpuMaintype != kPsychRadeon)) {
         return(FALSE);
     }
 
     // Driver is online. Enter polling loop:
     while (TRUE) {
-        // Read surface address registers:
-        primarySurface   = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_PRIMARY_SURFACE_ADDRESS : RADEON_D2GRPH_PRIMARY_SURFACE_ADDRESS, NULL);
-        secondarySurface = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_SECONDARY_SURFACE_ADDRESS : RADEON_D2GRPH_SECONDARY_SURFACE_ADDRESS, NULL);
-
-        // Read update status registers:
-        updateStatus     = PsychOSKDReadRegister(screenId, (PsychScreenToCrtcId(screenId, 0) < 1) ? RADEON_D1GRPH_UPDATE : RADEON_D2GRPH_UPDATE, NULL);
 
         PsychGetAdjustedPrecisionTimerSeconds(timestamp);
 
-        if (primarySurface!=windowRecord->gpu_preflip_Surfaces[0] || secondarySurface!=windowRecord->gpu_preflip_Surfaces[1] || (updateStatus & (RADEON_SURFACE_UPDATE_PENDING | RADEON_SURFACE_UPDATE_TAKEN)) || (*timestamp > deadline)) {
+        if ((PsychIsGPUPageflipUsed(windowRecord) > 0) || (*timestamp > deadline)) {
             // Abort condition: Exit loop.
             break;
         }
 
-        if (PsychPrefStateGet_Verbosity() > 9) {
-            printf("PTB-DEBUG: Head %i: primarySurface=%p : secondarySurface=%p : updateStatus=%i\n", PsychScreenToCrtcId(screenId, 0), primarySurface, secondarySurface, updateStatus);
-        }
-
         // Sleep slacky at least 200 microseconds, then retry:
         PsychYieldIntervalSeconds(0.0002);
     };
@@ -686,7 +790,7 @@ psych_bool PsychWaitForBufferswapPendingOrFinished(PsychWindowRecordType* window
     }
 
     // Return FALSE if bufferswap happened already, TRUE if swap is still pending:
-    return((updateStatus & RADEON_SURFACE_UPDATE_PENDING) ? TRUE : FALSE);
+    return((PsychIsGPUPageflipUsed(windowRecord) == 1) ? TRUE : FALSE);
 #else
     // On Windows, we always return "swap happened":
     return(FALSE);
@@ -697,6 +801,9 @@ psych_bool PsychWaitForBufferswapPendingOrFinished(PsychWindowRecordType* window
  *
  * Decodes hw register of NVidia GPU into GPU core id / chip family:
  * Returns 0 for unknown card, otherwise xx for NV_xx:
+ *
+ * Reference Linux nouveau-kms driver implementation in:
+ * nouveau/core/engine/device/base.c: nouveau_devobj_ctor()
  */
 unsigned int PsychGetNVidiaGPUType(PsychWindowRecordType* windowRecord)
 {
@@ -712,9 +819,9 @@ unsigned int PsychGetNVidiaGPUType(PsychWindowRecordType* windowRecord)
     if (reg0 == 0xffffffff) return(0xffffffff);
 
     /* We're dealing with >=NV10 */
-    if ((reg0 & 0x0f000000) > 0) {
-        /* Bit 27-20 contain the architecture in hex */
-        chipset = (reg0 & 0xff00000) >> 20;
+    if ((reg0 & 0x1f000000) > 0) {
+        /* Bit 28-20 contain the architecture in hex */
+        chipset = (reg0 & 0x1ff00000) >> 20;
         /* NV04 or NV05 */
     } else if ((reg0 & 0xff00fff0) == 0x20004000) {
         if (reg0 & 0x00f00000)
@@ -724,42 +831,51 @@ unsigned int PsychGetNVidiaGPUType(PsychWindowRecordType* windowRecord)
     } else
         chipset = 0xff;
 
-    switch (chipset & 0xf0) {
-        case 0x00:
+    switch (chipset & 0x1f0) {
+        case 0x000:
             // NV_04/05: RivaTNT , RivaTNT2
             card_type = 0x04;
             break;
-        case 0x10:
-        case 0x20:
-        case 0x30:
+        case 0x010:
+        case 0x020:
+        case 0x030:
             // NV30 or earlier: GeForce-5 / GeForceFX and earlier:
             card_type = chipset & 0xf0;
             break;
-        case 0x40:
-        case 0x60:
+        case 0x040:
+        case 0x060:
             // NV40: GeForce6/7 series:
-            card_type = 0x40;
+            card_type = 0x040;
             break;
-        case 0x50:
-        case 0x80:
-        case 0x90:
-        case 0xa0:
+        case 0x050:
+        case 0x080:
+        case 0x090:
+        case 0x0a0:
             // NV50: GeForce8/9/G100-G300.
-            card_type = 0x50;
+            card_type = 0x050;
             break;
-        case 0xc0:
+        case 0x0c0:
             // Fermi: GeForce G400/500 series:
-            card_type = 0xc0;
+            card_type = 0x0c0;
             break;
-        case 0xd0:
-        case 0xe0:
-        case 0xf0:
-            // Kepler: GeForce G600+ series: Up to 4 CRTC's.
-            card_type = 0xe0;
+        case 0x0d0:
+            // Fermi: But with 3rd gen scanout engine, but still only 2 CRTC's:
+            card_type = 0x0d0;
+            break;
+        case 0x0e0:
+        case 0x0f0:
+        case 0x100:
+            // Kepler: GeForce G600+ series: 3rd gen scanout engine, but now up to 4 CRTC's.
+            card_type = 0x0e0;
+            break;
+        case 0x110:
+        case 0x120:
+            // Maxwell: GeForce 750+ series: 3rd gen scanout engine, up to 4 CRTC's.
+            card_type = 0x110;
             break;
         default:
-            printf("PTB-DEBUG: Unknown NVidia chipset 0x%08x \n", reg0);
-            card_type = 0x00;
+            printf("PTB-DEBUG: Unknown NVidia chipset 0x%08x - Assuming latest generation.\n", reg0);
+            card_type = 0x000;
     }
 
     return(card_type);
@@ -862,7 +978,7 @@ void PsychInitScreenToHeadMappings(int numDisplays)
 
         for (j = 1; j < kPsychMaxPossibleCrtcs; j++) {
             displayScreensToPipes[i][j] = -1;
-            displayScreensToCrtcIds[i][j] = -1;   
+            displayScreensToCrtcIds[i][j] = -1;
         }
 
         // We also setup beamposition bias values to "neutral defaults":
@@ -1000,8 +1116,8 @@ void PsychSetBeamposCorrection(int screenId, int vblbias, int vbltotal)
             PsychOSIsKernelDriverAvailable(screenId)) {
 
             // Need to read different regs, depending on GPU generation:
-            if ((PsychGetNVidiaGPUType(NULL) >= 0xe0) || (PsychGetNVidiaGPUType(NULL) == 0x0)) {
-                // Auto-Detection. Read values directly from NV-E0 "Kepler" class and later hardware:
+            if ((PsychGetNVidiaGPUType(NULL) >= 0x0d0) || (PsychGetNVidiaGPUType(NULL) == 0x0)) {
+                // Auto-Detection. Read values directly from NV-D0 / E0-"Kepler" class and later hardware:
                 //
                 #if PSYCH_SYSTEM != PSYCH_WINDOWS
                 // VBLANKE end line of vertical blank - smaller than VBLANKS. Subtract VBLANKE + 1 to normalize to "scanline zero is start of active scanout":
