@@ -54,7 +54,8 @@ PsychError SCREENBeginOpenGL(void)
 		"state of your code from its internal state. However, if you provide sharecontext=1, then PTB will allow "
 		"your code to use and affect PTBs internal context. Only do this if you really know what you're doing! "
 		"If you provide sharecontext=2 then PTB will give you your own private context, but it will synchronize "
-		"the state of that context with its internal state - Seldomly needed, but here for your convenience. "
+		"the state of that context with its internal state - Seldomly needed, but here for your convenience. Caution: "
+        "sharecontext=2 is not supported on all operating systems and gpu's, e.g., not on OSX, so avoid if you can! "
 		"The context state isolation is as strict as possible without seriously affecting performance and functionality: "
 		"All OpenGL context state is separated, with two exceptions: The framebuffer binding (if any) is always synchronized "
 		"with PTB (and reset to zero when calling 'EndOpenGL' or another Screen command) to allow external code to transparently "
