@@ -1,33 +1,29 @@
 /*
-	ScreenPreferenceState.c		
-  
-	AUTHORS:
+    ScreenPreferenceState.c
+
+    AUTHORS:
 
     Allen.Ingling@nyu.edu           awi
-    mario.kleiner@tuebingen.mpg.de  mk
-  
-	PLATFORMS:	
-	
-		All.
-    
+    mario.kleiner.de@gmail.com      mk
 
-	HISTORY:
+    PLATFORMS:
 
-		2/28/04  awi		Created.   
-		5/30/05  mk           New preference setting screenSkipSyncTests: If set to TRUE, self-test and calibration will be as
-							short and sloppy as possible and some problematic conditions will not cause an abort.
-							One can trade-off correctness and accuracy of stimulus presentation against level of annoyance
-							during development/debugging of new experiments.
-		9/30/05  mk           new setting VisualDebugLevel: Defines how much visual feedback PTB should give about errors and
-							state: 0=none, 1=only errors, 2=also warnings, 3=also infos, 4=also blue bootup screen, 5=also visual test sheets.
-		3/7/06   awi        Added state for new preference flag SuppressAllWarnings. 
-  
-	DESCRIPTION:
-  
-		This file holds state for the Screen Preference command.
-  
-   
-  
+        All.
+
+    HISTORY:
+
+        2/28/04  awi        Created.
+        5/30/05  mk         New preference setting screenSkipSyncTests: If set to TRUE, self-test and calibration will be as
+                            short and sloppy as possible and some problematic conditions will not cause an abort.
+                            One can trade-off correctness and accuracy of stimulus presentation against level of annoyance
+                            during development/debugging of new experiments.
+        9/30/05  mk         new setting VisualDebugLevel: Defines how much visual feedback PTB should give about errors and
+                            state: 0=none, 1=only errors, 2=also warnings, 3=also infos, 4=also blue bootup screen, 5=also visual test sheets.
+        3/7/06   awi        Added state for new preference flag SuppressAllWarnings.
+
+    DESCRIPTION:
+
+        This file holds state for the Screen Preference command.
 */
 
 
@@ -46,52 +42,53 @@
 #define PTB_DEFAULTVIDCAPENGINE 3
 
 #if PSYCH_SYSTEM == PSYCH_LINUX
-#define INITIAL_DEFAULT_FONT_NAME		"Times"
-#define INITIAL_DEFAULT_FONT_SIZE		24
-#define INITIAL_DEFAULT_FONT_STYLE		0
+#define INITIAL_DEFAULT_FONT_NAME       "Times"
+#define INITIAL_DEFAULT_FONT_SIZE       24
+#define INITIAL_DEFAULT_FONT_STYLE      0
 #endif
 
 #if PSYCH_SYSTEM == PSYCH_OSX
-#define INITIAL_DEFAULT_FONT_NAME		"Geneva"
-#define INITIAL_DEFAULT_FONT_SIZE		12
-#define INITIAL_DEFAULT_FONT_STYLE		0
+#define INITIAL_DEFAULT_FONT_NAME       "Geneva"
+#define INITIAL_DEFAULT_FONT_SIZE       12
+#define INITIAL_DEFAULT_FONT_STYLE      0
 #endif
 
 #if PSYCH_SYSTEM == PSYCH_WINDOWS
-#define INITIAL_DEFAULT_FONT_NAME		"Courier New"
-#define INITIAL_DEFAULT_FONT_SIZE		18
-#define INITIAL_DEFAULT_FONT_STYLE		0
+#define INITIAL_DEFAULT_FONT_NAME       "Courier New"
+#define INITIAL_DEFAULT_FONT_SIZE       18
+#define INITIAL_DEFAULT_FONT_STYLE      0
 #endif
 
 //PsychTable preference state
-static int								psychTableVersion;				//there is no psych table yet, this is provided for the future. 
-static char								PsychTableCreator[]="Screen";   //there is no psych table yet, this is provided for the future.
+static int                              psychTableVersion;              //there is no psych table yet, this is provided for the future.
+static char                             PsychTableCreator[]="Screen";   //there is no psych table yet, this is provided for the future.
 //Text preference state
-static int								defaultTextYPositionIsBaseline; // Use new style of text positioning by default: y-pos is top of text.
+static int                              defaultTextYPositionIsBaseline; // Use new style of text positioning by default: y-pos is top of text.
 #define MAX_DEFAULT_FONT_NAME_LENGTH    256
-static char								defaultFontName[MAX_DEFAULT_FONT_NAME_LENGTH];
-static int								defaultTextSize;
-static int								defaultTextStyle;				// 0=normal,1=bold,2=italic,4=underline,8=outline,32=condense,64=extend
+static char                             defaultFontName[MAX_DEFAULT_FONT_NAME_LENGTH];
+static int                              defaultTextSize;
+static int                              defaultTextStyle;               // 0=normal,1=bold,2=italic,4=underline,8=outline,32=condense,64=extend
 static psych_bool                       textAlphaBlending;
-static int								textAntiAliasing;				// -1=System defined (don't care), 0=Always off, 1=Always on.
-static int								textRenderer;					// 0=Default OS specific (fast one), 1=OS specific High quality.
-static int                              screenSkipSyncTests;			// 0=Do full synctests, abort on failure, 1=Reduced tests, continue with warning, 2=Skip'em
+static int                              textAntiAliasing;               // -1=System defined (don't care), 0=Always off, 1=Always on.
+static int                              textRenderer;                   // 0=Default OS specific (fast one), 1=OS specific High quality.
+static int                              screenSkipSyncTests;            // 0=Do full synctests, abort on failure, 1=Reduced tests, continue with warning, 2=Skip'em
 //Debug preference state
-static psych_bool						TimeMakeTextureFlag;
-static int								screenVisualDebugLevel;
+static psych_bool                       TimeMakeTextureFlag;
+static int                              screenVisualDebugLevel;
 static int                              screenConserveVRAM;
 // If EmulateOldPTB is set to true, then try to behave like the old OS-9 PTB:
 static psych_bool                       EmulateOldPTB;
 // Support for real 3D rendering enabled? Any non-zero value enables 3D rendering, a setting of 1 with defaults, values > 1 enable additional features. Disabled by default.
-static int								Enable_3d_gfx;
+static int                              Enable_3d_gfx;
 static int                              screenVBLTimestampingMode;
-static int								screenVBLEndlineOverride;		// Manual override for VTOTAL - Endline of VBL. -1 means "auto-detect" this is the default.
-static int								videoCaptureEngineId;			// Default video capture engine: 0 = Quicktime, 1 = LibDC1394 Firewire, 2 = ARVideo.
-static int								windowShieldingLevel;			// Level of priority of windowed onscreen window wrt. other windows:
-																		// From 0 for "behind everything" to 2000 for "in front of everything. Exact meaning of
-																		// number is OS specific. This value is used at window open time for each window.
-static double							frameRectLadderCorrection;		// Tweak factor to apply in SCREENFrameRect.c for different GPU's.
-static psych_bool						suppressAllWarnings;
+static int                              screenVBLEndlineOverride;       // Manual override for VTOTAL - Endline of VBL. -1 means "auto-detect" this is the default.
+static double                           screenVBLEndlineMaxFactor;      // Manual override for max VTOTAL as a multiplicator of VACTIVE.
+static int                              videoCaptureEngineId;           // Default video capture engine: 0 = Quicktime, 1 = LibDC1394 Firewire, 2 = ARVideo.
+static int                              windowShieldingLevel;           // Level of priority of windowed onscreen window wrt. other windows:
+                                                                        // From 0 for "behind everything" to 2000 for "in front of everything. Exact meaning of
+                                                                        // number is OS specific. This value is used at window open time for each window.
+static double                           frameRectLadderCorrection;      // Tweak factor to apply in SCREENFrameRect.c for different GPU's.
+static psych_bool                       suppressAllWarnings;
 
 // General level of verbosity:
 // 0 = Shut up.
@@ -100,14 +97,14 @@ static psych_bool						suppressAllWarnings;
 // 3 = Above + Basic Info, e.g., window properties and copyright. This is the default.
 // 4 = Lot's more debug output and infos.
 // 5 = Extreme debug output.
-static int								Verbosity;
+static int                              Verbosity;
 
 // Thresholds used during VBL sync tests and refresh rate measurement and calibration
 // in PsychOpenOnscreenWindow()
-static double							sync_maxStddev;					// Maximum standard deviation from mean duration in seconds.
-static double							sync_maxDeviation;				// Maximum deviation (in percent) between measured and OS reported reference frame duration.
-static double							sync_maxDuration;				// Maximum duration of a calibration run in seconds.
-static int								sync_minSamples;				// Minimum number of valid measurement samples needed.
+static double                           sync_maxStddev;                 // Maximum standard deviation from mean duration in seconds.
+static double                           sync_maxDeviation;              // Maximum deviation (in percent) between measured and OS reported reference frame duration.
+static double                           sync_maxDuration;               // Maximum duration of a calibration run in seconds.
+static int                              sync_minSamples;                // Minimum number of valid measurement samples needed.
 
 static int                              useGStreamer;                   // Use GStreamer for multi-media processing? 1==yes.
 
@@ -117,29 +114,30 @@ static int                              useGStreamer;                   // Use G
 // (re-)load of the MEX file, ie., at first invocation, or after a clear all, clear mex etc. 
 void PrepareScreenPreferences(void)
 {
-	//set the fake psych table version
-	psychTableVersion=20;
-	sprintf(PsychTableCreator, "Screen");
-	defaultTextYPositionIsBaseline=0;
-	defaultTextSize=INITIAL_DEFAULT_FONT_SIZE;
-	defaultTextStyle=INITIAL_DEFAULT_FONT_STYLE;
-	textAlphaBlending=FALSE;
-	textAntiAliasing=-1;
-	textRenderer=PTB_DEFAULT_TEXTRENDERER;
-	screenSkipSyncTests=0;
-	TimeMakeTextureFlag=FALSE;
-	screenVisualDebugLevel=4;
-	screenConserveVRAM=0;
-	EmulateOldPTB=FALSE;
-	Enable_3d_gfx=0;
-	screenVBLTimestampingMode = ((PSYCH_SYSTEM == PSYCH_LINUX) || (PSYCH_SYSTEM == PSYCH_WINDOWS)) ? 4 : 1;
-	screenVBLEndlineOverride=-1;
-	videoCaptureEngineId=PTB_DEFAULTVIDCAPENGINE;
-	windowShieldingLevel=2000;
-	frameRectLadderCorrection=-1.0;
-	suppressAllWarnings=FALSE;
+    //set the fake psych table version
+    psychTableVersion=20;
+    sprintf(PsychTableCreator, "Screen");
+    defaultTextYPositionIsBaseline=0;
+    defaultTextSize=INITIAL_DEFAULT_FONT_SIZE;
+    defaultTextStyle=INITIAL_DEFAULT_FONT_STYLE;
+    textAlphaBlending=FALSE;
+    textAntiAliasing=-1;
+    textRenderer=PTB_DEFAULT_TEXTRENDERER;
+    screenSkipSyncTests=0;
+    TimeMakeTextureFlag=FALSE;
+    screenVisualDebugLevel=4;
+    screenConserveVRAM=0;
+    EmulateOldPTB=FALSE;
+    Enable_3d_gfx=0;
+    screenVBLTimestampingMode = ((PSYCH_SYSTEM == PSYCH_LINUX) || (PSYCH_SYSTEM == PSYCH_WINDOWS)) ? 4 : 0;
+    screenVBLEndlineOverride=-1;
+    screenVBLEndlineMaxFactor=1.25;
+    videoCaptureEngineId=PTB_DEFAULTVIDCAPENGINE;
+    windowShieldingLevel=2000;
+    frameRectLadderCorrection=-1.0;
+    suppressAllWarnings=FALSE;
 
-	// Default level of verbosity is 3:
+    // Default level of verbosity is 3:
     Verbosity=3;
 
     // Early override via environment variable, if defined:
@@ -147,24 +145,24 @@ void PrepareScreenPreferences(void)
         Verbosity = atoi(getenv("PSYCH_SCREEN_VERBOSITY"));
     }
 
-	// Default synctest settings: 200 usec allowable max standard deviation from measured
-	// mean flip duration, at least 50 valid sync samples, at most 10% deviation between
-	// measured duration and reference duration (os reported or other), at most 5 seconds
-	// worst-case duration per calibration run:
-	PsychPrefStateSet_SynctestThresholds(0.000200, 50, 0.1, 5);
-	
-	// Initialize our locale setting for multibyte/singlebyte to unicode character conversion
-	// for Screen('DrawText') et al. to be the current default system locale, as defined by
-	// system settings and environment variables at startup of Matlab/Octave:
-	// N.B. This function is special as the affected state setting and routines are not defined
-	// here, but inside the Screen text handling routines, currently in SCREENDrawText.c
-	PsychSetUnicodeTextConversionLocale("");
-	PsychPrefStateSet_DefaultFontName(INITIAL_DEFAULT_FONT_NAME);
+    // Default synctest settings: 200 usec allowable max standard deviation from measured
+    // mean flip duration, at least 50 valid sync samples, at most 10% deviation between
+    // measured duration and reference duration (os reported or other), at most 5 seconds
+    // worst-case duration per calibration run:
+    PsychPrefStateSet_SynctestThresholds(0.000200, 50, 0.1, 5);
 
-	// Don't use GStreamer by default on 32-bit builds for OS/X and Windows:
-	PsychPrefStateSet_UseGStreamer(0);
+    // Initialize our locale setting for multibyte/singlebyte to unicode character conversion
+    // for Screen('DrawText') et al. to be the current default system locale, as defined by
+    // system settings and environment variables at startup of Matlab/Octave:
+    // N.B. This function is special as the affected state setting and routines are not defined
+    // here, but inside the Screen text handling routines, currently in SCREENDrawText.c
+    PsychSetUnicodeTextConversionLocale("");
+    PsychPrefStateSet_DefaultFontName(INITIAL_DEFAULT_FONT_NAME);
 
-	return;
+    // Don't use GStreamer by default on 32-bit builds for OS/X and Windows:
+    PsychPrefStateSet_UseGStreamer(0);
+
+    return;
 }
 
 //Accessors
@@ -178,7 +176,7 @@ preference: PsychTableVersion
 */
 int PsychPrefStateGet_PsychTableVersion(void)
 {
-	return(psychTableVersion);
+    return(psychTableVersion);
 }
 
 /*
@@ -186,7 +184,7 @@ preference: PsychTableCreator
 */
 const char *PsychPrefStateGet_PsychTableCreator(void)
 {
-	return(PsychTableCreator);
+    return(PsychTableCreator);
 }
 
 //****************************************************************************************************************
@@ -198,32 +196,32 @@ const char *PsychPrefStateGet_PsychTableCreator(void)
 // This setting can be overriden case-by-case with the optional 7th argument to 'DrawText':
 int PsychPrefStateGet_TextYPositionIsBaseline(void)
 {
-	return(defaultTextYPositionIsBaseline);
+    return(defaultTextYPositionIsBaseline);
 }
 
 void PsychPrefStateSet_TextYPositionIsBaseline(int textPosIsBaseline)
 {
-	defaultTextYPositionIsBaseline = (textPosIsBaseline > 0) ? 1 : 0;
+    defaultTextYPositionIsBaseline = (textPosIsBaseline > 0) ? 1 : 0;
 }
 
 int PsychPrefStateGet_TextAntiAliasing(void)
 {
-	return(textAntiAliasing);
+    return(textAntiAliasing);
 }
 
 void PsychPrefStateSet_TextAntiAliasing(int mode)
 {
-	textAntiAliasing = mode;
+    textAntiAliasing = mode;
 }
 
 int PsychPrefStateGet_TextRenderer(void)
 {
-	return(textRenderer);
+    return(textRenderer);
 }
 
 void PsychPrefStateSet_TextRenderer(int mode)
 {
-	textRenderer = mode;
+    textRenderer = mode;
 }
 
 /*
@@ -231,15 +229,15 @@ preference: DefaultFontName
 */
 void PsychPrefStateGet_DefaultFontName(const char **fontName )
 {
-	*fontName=defaultFontName;
+    *fontName=defaultFontName;
 }
 
 
 void PsychPrefStateSet_DefaultFontName(const char *newName)
 {
-	if(strlen(newName)+1 > MAX_DEFAULT_FONT_NAME_LENGTH)
-		PsychErrorExitMsg(PsychError_user, "Attempt to set a default font name using a string >255 characters");
-	strcpy(defaultFontName, newName);
+    if(strlen(newName)+1 > MAX_DEFAULT_FONT_NAME_LENGTH)
+        PsychErrorExitMsg(PsychError_user, "Attempt to set a default font name using a string >255 characters");
+    strcpy(defaultFontName, newName);
 }
 
 /*
@@ -247,12 +245,12 @@ preference: DefaultTextSize
 */
 int PsychPrefStateGet_DefaultTextSize(void)
 {
-	return(defaultTextSize);
+    return(defaultTextSize);
 }
 
 void PsychPrefStateSet_DefaultTextSize(int textSize)
 {
-	defaultTextSize=textSize;
+    defaultTextSize=textSize;
 }
 
 /*
@@ -260,12 +258,12 @@ preference: DefaultTextStyle
 */
 int PsychPrefStateGet_DefaultTextStyle(void)
 {
-	return(defaultTextStyle);
+    return(defaultTextStyle);
 }
 
 void PsychPrefStateSet_DefaultTextStyle(int textStyle)
 {
-	defaultTextStyle=textStyle;
+    defaultTextStyle=textStyle;
 }
 
 /*
@@ -273,15 +271,15 @@ preference: TextAlphaBlending
 */
 psych_bool PsychPrefStateGet_TextAlphaBlending(void)
 {
-	return(textAlphaBlending);
+    return(textAlphaBlending);
 }
 
 void PsychPrefStateSet_TextAlphaBlending(psych_bool enableFlag)
 {
-	textAlphaBlending=enableFlag;
+    textAlphaBlending=enableFlag;
 }
 
-// Screen self-test and calibration preferences for syncing to VBL and such...  
+// Screen self-test and calibration preferences for syncing to VBL and such...
 int PsychPrefStateGet_SkipSyncTests(void)
 {
     return(screenSkipSyncTests);
@@ -292,7 +290,7 @@ void PsychPrefStateSet_SkipSyncTests(int level)
     screenSkipSyncTests = level;
 }
 
-// Screen debug level for output of visual feedback signals...  
+// Screen debug level for output of visual feedback signals...
 int PsychPrefStateGet_VisualDebugLevel(void)
 {
     return(screenVisualDebugLevel);
@@ -337,6 +335,17 @@ void PsychPrefStateSet_VBLEndlineOverride(int level)
     screenVBLEndlineOverride = level;
 }
 
+// Override for display endline multiplicator, relative to VACTIVE:
+double PsychPrefStateGet_VBLEndlineMaxFactor(void)
+{
+    return(screenVBLEndlineMaxFactor);
+}
+
+void PsychPrefStateSet_VBLEndlineMaxFactor(double inputDoubleValue)
+{
+    screenVBLEndlineMaxFactor = inputDoubleValue;
+}
+
 // Settings for conserving VRAM usage by disabling certain features.
 // Current constants (defined in ScreenTypes.h) that can be or'ed together:
 // kPsychDisableAUXBuffers = Don't use AUX buffers, disable associated features.
@@ -370,11 +379,11 @@ psych_bool PsychPrefStateGet_EmulateOldPTB(void)
 void PsychPrefStateSet_EmulateOldPTB(psych_bool level)
 {
     EmulateOldPTB = level;
-	// When emulation for old PTB gets enabled, we change the default for
-	// text baseline to 'on' -- The behaviour of old PTB.
-	#if PSYCH_SYSTEM == PSYCH_OSX
-		if (EmulateOldPTB>0) defaultTextYPositionIsBaseline=1;
-	#endif
+    // When emulation for old PTB gets enabled, we change the default for
+    // text baseline to 'on' -- The behaviour of old PTB.
+    #if PSYCH_SYSTEM == PSYCH_OSX
+        if (EmulateOldPTB>0) defaultTextYPositionIsBaseline=1;
+    #endif
 }
 
 // Enable switch for 3D graphics support. If set to true, PTB will allocate stencil-
@@ -388,19 +397,19 @@ int PsychPrefStateGet_3DGfx(void)
 
 void PsychPrefStateSet_3DGfx(int level)
 {
-	if (level < 0) PsychErrorExitMsg(PsychError_invalidIntegerArg, "3D graphics preference setting must be a non-negative integer value! You passed a negative one.");
+    if (level < 0) PsychErrorExitMsg(PsychError_invalidIntegerArg, "3D graphics preference setting must be a non-negative integer value! You passed a negative one.");
     Enable_3d_gfx = level;
 }
 
 // Default for selection of video capture engine:
 int PsychPrefStateGet_VideoCaptureEngine(void)
 {
-	return(videoCaptureEngineId);
+    return(videoCaptureEngineId);
 }
 
 void PsychPrefStateSet_VideoCaptureEngine(int mode)
 {
-	videoCaptureEngineId = mode;
+    videoCaptureEngineId = mode;
 }
 
 int PsychPrefStateGet_WindowShieldingLevel(void)
@@ -416,33 +425,33 @@ void PsychPrefStateSet_WindowShieldingLevel(int level)
 // Correction tweak offset for proper Screen('FrameRect') behaviour:
 void PsychPrefStateSet_FrameRectCorrection(double level)
 {
-	frameRectLadderCorrection = level;
+    frameRectLadderCorrection = level;
 }
 
 double PsychPrefStateGet_FrameRectCorrection(void)
 {
-	return(frameRectLadderCorrection);
+    return(frameRectLadderCorrection);
 }
 
 // Tweakable parameters for VBL sync tests and refresh rate calibration:
 void PsychPrefStateSet_SynctestThresholds(double maxStddev, int minSamples, double maxDeviation, double maxDuration)
 {
-	if (maxStddev <= 0.0) PsychErrorExitMsg(PsychError_user, "Invalid (<= 0) maximum standard deviation provided!");
-	if (maxDeviation <= 0.0 || maxDeviation > 1.0) PsychErrorExitMsg(PsychError_user, "Invalid (not in range 0.0 - 1.0) maximum deviation from reference framerate provided!");
-	if (maxDuration <= 0.0) PsychErrorExitMsg(PsychError_user, "Invalid (<= 0) maximum duration of calibration procedure provided!");
-	if (minSamples < 0) PsychErrorExitMsg(PsychError_user, "Invalid (negative) minimum number of samples provided!");
-	sync_maxStddev = maxStddev;
-	sync_maxDeviation = maxDeviation;
-	sync_maxDuration = maxDuration;
-	sync_minSamples = minSamples;
+    if (maxStddev <= 0.0) PsychErrorExitMsg(PsychError_user, "Invalid (<= 0) maximum standard deviation provided!");
+    if (maxDeviation <= 0.0 || maxDeviation > 1.0) PsychErrorExitMsg(PsychError_user, "Invalid (not in range 0.0 - 1.0) maximum deviation from reference framerate provided!");
+    if (maxDuration <= 0.0) PsychErrorExitMsg(PsychError_user, "Invalid (<= 0) maximum duration of calibration procedure provided!");
+    if (minSamples < 0) PsychErrorExitMsg(PsychError_user, "Invalid (negative) minimum number of samples provided!");
+    sync_maxStddev = maxStddev;
+    sync_maxDeviation = maxDeviation;
+    sync_maxDuration = maxDuration;
+    sync_minSamples = minSamples;
 }
 
 void PsychPrefStateGet_SynctestThresholds(double* maxStddev, int* minSamples, double* maxDeviation, double* maxDuration)
 {
-	*maxStddev    = sync_maxStddev;
-	*maxDeviation = sync_maxDeviation; 
-	*maxDuration  = sync_maxDuration; 
-	*minSamples   = sync_minSamples; 
+    *maxStddev    = sync_maxStddev;
+    *maxDeviation = sync_maxDeviation;
+    *maxDuration  = sync_maxDuration;
+    *minSamples   = sync_minSamples;
 }
 
 //****************************************************************************************************************
@@ -450,45 +459,45 @@ void PsychPrefStateGet_SynctestThresholds(double* maxStddev, int* minSamples, do
 
 psych_bool PsychPrefStateGet_DebugMakeTexture(void)
 {
-	return(TimeMakeTextureFlag);
+    return(TimeMakeTextureFlag);
 }
 
 void PsychPrefStateSet_DebugMakeTexture(psych_bool setFlag)
 {
-	TimeMakeTextureFlag=setFlag;
+    TimeMakeTextureFlag=setFlag;
 }
 
 psych_bool PsychPrefStateGet_SuppressAllWarnings(void)
 {
-	return(suppressAllWarnings);
+    return(suppressAllWarnings);
 }
 
 void PsychPrefStateSet_SuppressAllWarnings(psych_bool setFlag)
 {
-	suppressAllWarnings=setFlag;
+    suppressAllWarnings=setFlag;
 }
 
 // Level of verbosity:
 int PsychPrefStateGet_Verbosity(void)
 {
-	// Clamp level of verbosity to max. 1 if suppression of warnings is requested:
-	if (suppressAllWarnings && Verbosity>1) return(1); 
-	return(Verbosity);
+    // Clamp level of verbosity to max. 1 if suppression of warnings is requested:
+    if (suppressAllWarnings && Verbosity>1) return(1);
+    return(Verbosity);
 }
 
 void PsychPrefStateSet_Verbosity(int level)
 {
-	Verbosity = level;
+    Verbosity = level;
 }
 
 void PsychPrefStateSet_UseGStreamer(int value)
 {
-	useGStreamer = value;
+    useGStreamer = value;
 }
 
 int PsychPrefStateGet_UseGStreamer(void)
 {
-	return(useGStreamer);
+    return(useGStreamer);
 }
 
 // Screen -> Head mappings: These are special, because the default
@@ -497,16 +506,16 @@ int PsychPrefStateGet_UseGStreamer(void)
 // so these are just wrappers around the true accessor functions:
 void PsychPrefStateSet_ScreenToHead(int screenId, int headId, int crtcId, int rankId)
 {
-	PsychSetScreenToHead(screenId, headId, rankId);
+    PsychSetScreenToHead(screenId, headId, rankId);
     PsychSetScreenToCrtcId(screenId, crtcId, rankId);
 }
 
 int PsychPrefStateGet_ScreenToHead(int screenId, int rankId)
 {
-	return(PsychScreenToHead(screenId, rankId));
+    return(PsychScreenToHead(screenId, rankId));
 }
 
 int PsychPrefStateGet_ScreenToCrtcId(int screenId, int rankId)
 {
-	return(PsychScreenToCrtcId(screenId, rankId));
+    return(PsychScreenToCrtcId(screenId, rankId));
 }
