@@ -40,6 +40,17 @@ function [warpstruct, filterMode] = CreateDisplayWarp(window, calibfilename, sho
 % surface. This is the recommended calibration procedure for most cases -
 % Proven in real-world use on many different display types.
 %
+% When used with DisplayUndistortionBVL, the GeometryCorrection takes
+% up to three optional parameters:
+%
+% PsychImaging('AddTask', 'LeftView', 'GeometryCorrection', 'mycalib.mat' [, debug=0][, xsampling=73][,ysampling=53][, replicate=[1,1]]);
+% xsampling and ysampling specify the horizontal and vertical number of subdivisions
+% for the warpmesh that is used for undistortion - higher numbers give more
+% close approximations but increase drawing time. replicate is a vector which
+% describes how often the mesh should be replicated into horizontal and vertical
+% direction. Values other than the default [1,1] only make sense for special display
+% devices like ProPixx.
+%
 % DisplayUndistortionBezier.m -- Undistortion based on a NURBS surface (Non
 % uniform rational bezier spline surface). A simple procedure.
 %
@@ -67,6 +78,7 @@ function [warpstruct, filterMode] = CreateDisplayWarp(window, calibfilename, sho
 % 25.8.2011 Adapt code for sphere projection undistortion to new convention
 %           of Ingmar Schneider's shader code. (MK).
 % 27.7.2012 Add support for DisplayUndistortionCSV() aka "NVidia Warp-API" format (MK).
+% 14.3.2015 Add support for Propixx and similar devices via mesh replication to the BVL method (MK).
 %
 
 % Global GL handle for access to OpenGL constants needed in setup:
@@ -347,11 +359,40 @@ switch(calib.warptype)
                 yLoomSize = varargin{2};
             end
         end
-        
+
+        if (length(varargin) >= 3) && ~isempty(varargin{3})
+            % Subdivision/Replication [xdiv, ydiv] given. We shall
+            % generate a calibration display list which only has
+            % 1/xdiv the window widht, 1/ydiv the window height,
+            % but is replicated xdiv x ydiv times. E.g., a [2,2]
+            % subdivision will split the window into 4 quadrants and
+            % apply the undistortion independently to each quadrants.
+            % This is, e.g., useful for special display modes of special
+            % display devices like the ProPrixx.
+            subdiv = varargin{3};
+            if ~length(subdiv) == 2 || ~isnumeric(subdiv)
+                error('CreateDisplayWarp: Provided optional subdiv parameter is not a [xrep, yrep] vector as required.');
+            end
+
+            xrep = subdiv(1);
+            yrep = subdiv(2);
+
+            if xrep ~=round(xrep) || yrep ~= round(yrep)
+                error('CreateDisplayWarp: Provided subdiv parameter [xrep, yrep] does not contain integral values as required.');
+            end
+
+            % Adapt width and height of target area for calibration:
+            winWidth = winWidth / xrep;
+            winHeight = winHeight / yrep;
+        else
+            xrep = 1;
+            yrep = 1;
+        end
+
         % Compute vertex- and texcoord-arrays that define the mesh
         % of quadrilaterals which should be rendered (with the stimulus
         % texture applied) to create the undistortion warp:
-        [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(winWidth, winHeight, calib.scal, showCalibOutput, xLoomSize, yLoomSize);
+        [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(winWidth, winHeight, calib.scal, showCalibOutput, xLoomSize, yLoomSize, xrep, yrep);
 
         % Build the unwarp mesh display list within the OpenGL context of
         % Psychtoolbox:
@@ -448,8 +489,8 @@ return;
 
 % --- Helper routines for setup of the calibration method 'BVLDisplayList' ---
 
-function [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(windowWidth, windowHeight, scal, showCalibOutput, xLoomSize, yLoomSize)
-% [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(windowWidth, windowHeight, scal, showCalibOutput, xLoomSize, yLoomSize)
+function [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(windowWidth, windowHeight, scal, showCalibOutput, xLoomSize, yLoomSize, xrep, yrep)
+% [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(windowWidth, windowHeight, scal, showCalibOutput, xLoomSize, yLoomSize, xrep, yrep)
 %
 % Internal helper routine: Called by CreateDisplayWarp.m, which is in turn
 % called by PsychImaging.m. Implements the geometric display calibration
@@ -466,13 +507,13 @@ function [xyzcalibpos, xytexcoords] = BVLComputeWarpMesh(windowWidth, windowHeig
 %
 
 % Check resolution against the calibration file resolutions:
-if (windowWidth ~= scal.rect(3)) || (windowHeight ~= scal.rect(4))
+if ((windowWidth * xrep) ~= RectWidth(scal.rect)) || ((windowHeight * yrep) ~= RectHeight(scal.rect))
     fprintf('\n\nCALIBRATION WARNING!\n');
     fprintf('Onscreen window resolution (%d, %d) does not match ', ...
         windowWidth, windowHeight);
     fprintf('the resolution used in the calibration file (%d, %d)!\n', ...
-        scal.rect(3), scal.rect(4));
-    fprintf('Using the window resolution to draw the stimuli.\n');
+        RectWidth(scal.rect), RectHeight(scal.rect));
+    fprintf('Using the window resolution to draw the stimuli, scaling down proportionally.\n');
     fprintf('\n\n');
 end
 
@@ -492,8 +533,14 @@ if isempty(yLoomSize)
     yLoomSize   = 53; %length(YVALUES)
 end
 
-xStep       = windowWidth / (xLoomSize-1);
-yStep       = windowHeight / (yLoomSize-1);
+% Compute sampling positions for the calibration data:
+xStep       = RectWidth(scal.rect) / (xLoomSize-1);
+yStep       = RectHeight(scal.rect) / (yLoomSize-1);
+
+% Compute scale factor in case the output window size doesn't
+% match the size used for generating the scal calibration data:
+scaleX = windowWidth / RectWidth(scal.rect);
+scaleY = windowHeight / RectHeight(scal.rect);
 
 numVerts    = xLoomSize * yLoomSize;
 % vertexCoords = Nx2 array, N rows of [x y] pairs.
@@ -546,6 +593,13 @@ else
     vertexCoordsFit(:,2)= griddata(scal.XCALIBDOTS, scal.YCALIBDOTS, scal.SELECTYCALIBDOTS, vertexCoords(:,1), vertexCoords(:,2));
 end
 
+% Rescale input/output positions to fit output window:
+vertexCoords(:,1) = vertexCoords(:,1) * scaleX;
+vertexCoordsFit(:,1) = vertexCoordsFit(:,1) * scaleX;
+
+vertexCoords(:,2) = vertexCoords(:,2) * scaleY;
+vertexCoordsFit(:,2) = vertexCoordsFit(:,2) * scaleY;
+
 % Some debug plots, if requested:
 if showCalibOutput
     figure(10)
@@ -569,13 +623,25 @@ end
 % as our internal vertex/texcoord assignment is upside down wrt. original
 % Banks lab calibration:
 vertexCoords(:,2) = windowHeight - vertexCoords(:,2);
-[xyzcalibpos, xytexcoords] = BVLGeneratetextcoord(yLoomSize, xLoomSize, vertexCoords, vertexCoordsFit, showCalibOutput);
+
+xyzcalibpos = [];
+xytexcoords = [];
+for x = 0:xrep-1
+    for y = 0:yrep-1
+        xoffset = x * windowWidth;
+        yoffset = y * windowHeight;
+        [newxyzcalibpos, newxytexcoords] = BVLGeneratetextcoord(yLoomSize, xLoomSize, vertexCoords, vertexCoordsFit, showCalibOutput, xoffset, yoffset);
+
+        xyzcalibpos = [xyzcalibpos, newxyzcalibpos];
+        xytexcoords = [xytexcoords, newxytexcoords];
+    end
+end
 
 % Done. Return results:
 return;
 
 
-function [xyzcalibpos, xytexcoords]=BVLGeneratetextcoord(yLoomSize, xLoomSize, vertexCoords, vertexCoordsFit, showCalibOutput)
+function [xyzcalibpos, xytexcoords]=BVLGeneratetextcoord(yLoomSize, xLoomSize, vertexCoords, vertexCoordsFit, showCalibOutput, xoffset, yoffset)
 % Internal helper routine: Called by BVLComputeWarpMesh.m.
 % Implements the geometric display calibration and undistortion procedure
 % developed by the Banks Vision Lab at UC Berkeley.
@@ -643,10 +709,10 @@ for y=1:(yLoomSize-1)
     end
 end
 
-xyzcalibpos(1:2:end) = xverts;
-xyzcalibpos(2:2:end) = yverts;
-xytexcoords(1:2:end) = xtemp;
-xytexcoords(2:2:end) = ytemp;
+xyzcalibpos(1:2:end) = xverts + xoffset;
+xyzcalibpos(2:2:end) = yverts + yoffset;
+xytexcoords(1:2:end) = xtemp + xoffset;
+xytexcoords(2:2:end) = ytemp + yoffset;
 
 return;
 
