@@ -59,6 +59,7 @@ function UpdatePsychtoolbox(targetdirectory, targetRevision)
 % 09/14/12 mk  Drop support for Octave on MS-Windows.
 % 09/14/12 mk  Drop support for 32-Bit Octave on OSX.
 % 07/02/13 mk  Drop support for 32-Bit Matlab on OSX, and thereby for 32-Bit OSX.
+% 05/18/14 mk  No support for 32-Bit Matlab on Linux and Windows anymore for 3.0.12.
 
 % Flush all MEX files: This is needed at least on M$-Windows for SVN to
 % work if Screen et al. are still loaded.
@@ -92,6 +93,16 @@ if any(isspace(targetdirectory))
     fprintf('The targetdirectory spec contains white-space. This should work, but has not been tested extensively.\n');
 end
 
+% Check if this is 32-Bit Matlab on Windows or Linux, which we don't support anymore:
+if (strcmp(computer, 'PCWIN') || strcmp(computer, 'GLNX86'))
+    fprintf('Psychtoolbox 3.0.12 and later do no longer work with 32-Bit versions of Matlab.\n');
+    fprintf('You need to upgrade to a supported 64-Bit version of Octave or Matlab. 32-Bit Octave is still\n');
+    fprintf('supported on GNU/Linux.\n');
+    fprintf('If you must use a legacy 32-Bit Matlab environment, you can call this function\n');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.11'', which does support 32-Bit Matlab on Linux and Windows.\n');
+    error('Tried to setup on 32-Bit Matlab, which is no longer supported.');
+end
+
 % Check if this is 32-Bit Octave or 32-Bit Matlab on OSX, which we don't support anymore:
 if (~isempty(strfind(computer, 'apple-darwin')) || strcmp(computer,'MACI')) && isempty(strfind(computer, '64'))
     fprintf('Psychtoolbox 3.0.11 and later do no longer work with 32-Bit versions of Octave or Matlab on OSX.\n');
